PcapHeader

Struct PcapHeader 

pub struct PcapHeader {
    pub version_major: u16,
    pub version_minor: u16,
    pub ts_correction: i32,
    pub ts_accuracy: u32,
    pub snaplen: u32,
    pub datalink: DataLink,
    pub ts_resolution: TsResolution,
    pub endianness: Endianness,
}
Pcap Global Header

Fields

version_major: u16

Major version number

version_minor: u16

Minor version number

ts_correction: i32

GMT to local timezone correction, should always be 0

ts_accuracy: u32

Timestamp accuracy, should always be 0

snaplen: u32

Max length of captured packet, typically 65535

datalink: DataLink

DataLink type (first layer in the packet)

ts_resolution: TsResolution

Timestamp resolution of the pcap (microsecond or nanosecond)

endianness: Endianness

Endianness of the pcap (excluding the packet data)

Implementations

Source

impl PcapHeader

pub fn from_slice(slice: &[u8]) -> PcapResult<(&[u8], PcapHeader)>

Creates a new PcapHeader from a slice of bytes.

Returns an error if the reader doesn’t contain a valid pcap or if there is a reading error.

PcapError::IncompleteBuffer indicates that there is not enough data in the buffer.

pub fn write_to<W: Write>(&self, writer: &mut W) -> PcapResult<usize>

Writes a PcapHeader to a writer.

Uses the endianness of the header.