TsResolution

Struct TsResolution 

pub struct TsResolution(/* private fields */);
Timestamp resolution of an interface.

Implementations

Source

impl TsResolution

pub const MICRO: Self

Micro-second resolution

pub const MILLI: Self

Milli-second resolution

pub const NANO: Self

Nano-second resolution

pub const SEC: Self

Second resolution

pub fn new(ts_resol: u8) -> Result<Self, PcapError>

Creates a new TsResolution from an u8 if is it in the range [0-9].

pub fn to_nano_secs(&self) -> u32

Returns the number of nanoseconds coresponding to the TsResolution.

pub fn to_raw(&self) -> u8

Returns the number of nanoseconds coresponding to the TsResolution in 10^-ts.